@@ -1,11 +1,10 @@
 import random
 
 from .additive_simulation import SimpleNeighborhood, OmniSimulation
-from .data import *
 from .progress import ProgressBar
 
 
-def run_mode(goal, dimension, lattice):
+def run_mode(goal, dimension, lattice, windows_mode):
     simulation = OmniSimulation(SimpleNeighborhood(lattice), None, tuple([0] * (1 + dimension)))
 
     p = ProgressBar(goal, lambda: simulation.energy)
@@ -14,4 +13,4 @@ def run_mode(goal, dimension, lattice):
         p(i)
         simulation.add_atom(lambda l: random.randrange(l))
 
-    simulation.interactive(dimension)
+    simulation.interactive(dimension, color=not windows_mode)
